@@ -16,7 +16,7 @@ Usage::
     session_client: IoTDeviceAdvisorClient = session.client("iotdeviceadvisor")
     ```
 """
-from mypy_boto3_iotdeviceadvisor.client import IoTDeviceAdvisorClient
+from .client import IoTDeviceAdvisorClient
 
 Client = IoTDeviceAdvisorClient
 
